# Syncing Tags with the Current Lifecycle Phases
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/syncing-tags-with-current-lifecycle-phases#overview)
  * [Configuration](https://help.sap.com/docs/leanix/ea/syncing-tags-with-current-lifecycle-phases#configuration)
  * [Script](https://help.sap.com/docs/leanix/ea/syncing-tags-with-current-lifecycle-phases#script)


Configure an automation with a script to add tags that match the current lifecycle phase to fact sheets.
